# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Array-Diff
Epoch:		1
Version:	0.09
Release:	14.%{__distinit}%{__distvers}
Summary:	Find the differences between two arrays
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Array-Diff
Source0:	https://cpan.metacpan.org/modules/by-module/Array/Array-Diff-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Algorithm::Diff) >= 1.19
BuildRequires:	perl(Algorithm::Diff::XS)
BuildRequires:	perl(base)
BuildRequires:	perl(Class::Accessor::Fast)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Test::More)
# Optional Tests
BuildRequires:	perl(Test::Pod) >= 1.00
BuildRequires:	perl(Test::Pod::Coverage) >= 1.04
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
# For performance
Requires:	perl(Algorithm::Diff::XS)

%description
This module compares two arrays and returns the added or deleted elements in
two separate arrays. It's a simple wrapper around Algorithm::Diff.

If you need more complex array tools, check Array::Compare.

%prep
%setup -q -n Array-Diff-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/Array/
%{_mandir}/man3/Array::Diff.3*

%changelog
* Wed Mar  8 2023 Paul Howarth <paul@city-fan.org> - 1:0.09-14
- Use SPDX-format license tag
- Drop support for building with rpm < 4.9
- Use %%license unconditionally

* Fri May 10 2019 Paul Howarth <paul@city-fan.org> - 1:0.09-1
- Update to 0.09
  - Set minimum Perl version in metadata (GH#1)
  - Clarified in the doc that the arrays must be sorted (CPAN RT#39184)

* Wed May  8 2019 Paul Howarth <paul@city-fan.org> - 1:0.08-1
- Update to 0.08
  - Switched to Dist::Zilla
  - Added version dependency for Algorithm::Diff in Array/Diff.pm
  - Added a bunch of entries to SEE ALSO
- Switch upstream from search.cpan.org to metacpan.org

* Mon May 15 2017 Paul Howarth <paul@city-fan.org> - 1:0.07-23
- Fix building on Perl without '.' in @INC
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Mon Aug  1 2016 Paul Howarth <paul@city-fan.org> - 1:0.07-21
- Fix FTBFS when perl is not in the minimal buildroot
- Classify buildreqs by usage
- Simplify find command using -delete

* Sun Aug 31 2014 Paul Howarth <paul@city-fan.org> - 1:0.07-16
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Wed Jul 17 2013 Paul Howarth <paul@city-fan.org> - 1:0.07-12
- Perl 5.18 rebuild

* Mon Jul  1 2013 Paul Howarth <paul@city-fan.org> - 1:0.07-9
- BR: perl(ExtUtils::MakeMaker)

* Wed Jun 27 2012 Paul Howarth <paul@city-fan.org> - 1:0.07-8
- BR: perl(base), perl(Carp), perl(Cwd), perl(File::Path) and perl(File::Spec)

* Tue Mar  6 2012 Paul Howarth <paul@city-fan.org> - 1:0.07-7
- Explicitly require perl(Class::Accessor::Fast) if we have rpm < 4.9
- Don't need to remove empty directories from buildroot
- Drop compatibility with distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Tue Jun 21 2011 Paul Howarth <paul@city-fan.org> - 1:0.07-5
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Mar 16 2011 Paul Howarth <paul@city-fan.org> - 1:0.07-4
- Import from Fedora

* Tue Feb  8 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:0.07-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Jan 25 2011 Daniel P. Berrange <berrange@redhat.com> - 1:0.07-2
- Bump epoch to ensure 0.07 is considered newer than 0.05002 (#672463)

* Fri Dec 17 2010 Daniel P. Berrange <berrange@redhat.com> - 0.07-1
- Update to 0.07 release

* Wed Dec 15 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.05002-6
- Rebuild to fix problems with vendorarch/lib (#661697)

* Thu Apr 29 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.05002-5
- Mass rebuild with perl-5.12.0

* Tue Jan 12 2010 Daniel P. Berrange <berrange@redhat.com> - 0.05002-4
- Fix source URL

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.05002-3
- Rebuild against perl 5.10.1

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.05002-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Jul 22 2009 Daniel P. Berrange <berrange@redhat.com> - 0.05002-1
- Update to new 0.05002 release

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.04-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Feb  8 2008 Tom "spot" Callaway <tcallawa@redhat.com> 0.04-3
- Rebuild for new perl

* Fri Dec 21 2007 Daniel P. Berrange <berrange@redhat.com> 0.04-2.fc9
- Added Test::Pod and Test::Pod::Coverage build requires

* Fri Dec 21 2007 Daniel P. Berrange <berrange@redhat.com> 0.04-1.fc9
- Specfile autogenerated by cpanspec 1.73
